## [1.6.4](https://github.com/BenTenmann/setriq/compare/deploy-1.6.3...deploy-1.6.4) (2022-12-21)


### Bug Fixes

* **ci:** add pybind dep to source dist ([#26](https://github.com/BenTenmann/setriq/issues/26)) ([e64979e](https://github.com/BenTenmann/setriq/commit/e64979ea6d60e64dbfcb37cea561d47993e9df5d))

## [1.6.3](https://github.com/BenTenmann/setriq/compare/deploy-1.6.2...deploy-1.6.3) (2022-12-21)


### Bug Fixes

* **ci:** try new filters + update gh-pages dependency ([a030b27](https://github.com/BenTenmann/setriq/commit/a030b27184c77e57a7be28f17043684a28d251e2))

## [1.6.2](https://github.com/BenTenmann/setriq/compare/deploy-1.6.1...deploy-1.6.2) (2022-12-19)


### Bug Fixes

* **ci:** update triggers ([55958a2](https://github.com/BenTenmann/setriq/commit/55958a22b2b9093dacb11aa1d53e21081be69e09))

## [1.6.1](https://github.com/BenTenmann/setriq/compare/deploy-1.6.0...deploy-1.6.1) (2022-12-18)


### Bug Fixes

* **ci:** bump semrel package versions ([dc076ec](https://github.com/BenTenmann/setriq/commit/dc076eca0638c7679aa573e1f0e7cf449869392e))
* **ci:** trigger CI ([#21](https://github.com/BenTenmann/setriq/issues/21)) ([0830f4a](https://github.com/BenTenmann/setriq/commit/0830f4af538a3502fc104a4a38eb80c6aeb4dc47))
* **ci:** update docker image to correct tag ([f02bac8](https://github.com/BenTenmann/setriq/commit/f02bac80306e6dca86a776f46b5b4cb7fc36bb08))

# [1.6.0](https://github.com/BenTenmann/setriq/compare/deploy-1.5.0...deploy-1.6.0) (2022-09-10)


### Features

* **lcs:** add new metrics ([b87f77e](https://github.com/BenTenmann/setriq/commit/b87f77e0429050bbb3bda70834e9874e1715221a))

# [1.5.0](https://github.com/BenTenmann/setriq/compare/deploy-1.4.2...deploy-1.5.0) (2022-06-05)


### Features

* **distances:** add hamming, jaro and jaro-winkler ([d9f7154](https://github.com/BenTenmann/setriq/commit/d9f7154fac2787ff80300be8c840c8ba9e5f989b))
* add landau vishkin algo ([87783fe](https://github.com/BenTenmann/setriq/commit/87783fe0044fab9c2b7142277aa464294912f89b))

## [1.4.2](https://github.com/BenTenmann/setriq/compare/deploy-1.4.1...deploy-1.4.2) (2022-01-29)


### Bug Fixes

* setup.py refactor ([663ad3d](https://github.com/BenTenmann/setriq/commit/663ad3da308ff32f8a38f67fee71fed647961e02))

## [1.4.1](https://github.com/BenTenmann/setriq/compare/deploy-1.4.0...deploy-1.4.1) (2022-01-29)


### Bug Fixes

* implicit conversion ([9720c4e](https://github.com/BenTenmann/setriq/commit/9720c4e9891a36947c469dd02e2e906bf0404339))
* implicit conversion ([b965d3f](https://github.com/BenTenmann/setriq/commit/b965d3f790fdc3ab4375bd6a0d40334fc92adba0))
* major refactor ([6735f13](https://github.com/BenTenmann/setriq/commit/6735f13b29bf23b0a0d264967718be3f98f3df7f))
* pass metric by value ([ba8f7b6](https://github.com/BenTenmann/setriq/commit/ba8f7b6817de73d5862c401ffdd16b240a27ff84))
* update string indexing ([145430b](https://github.com/BenTenmann/setriq/commit/145430bfb3ab62e53f1b54ddcb4b2fe7513ca3da))

# [1.4.0](https://github.com/BenTenmann/setriq/compare/deploy-1.3.1...deploy-1.4.0) (2022-01-15)


### Features

* add affine option to sw ([d96d1fd](https://github.com/BenTenmann/setriq/commit/d96d1fd1dbfbb1b7c5efa37603924334bcacc06d))

## [1.3.1](https://github.com/BenTenmann/setriq/compare/deploy-1.3.0...deploy-1.3.1) (2022-01-08)


### Bug Fixes

* pin setuptools ([d576789](https://github.com/BenTenmann/setriq/commit/d576789fc0469da93b3a4d54b25b73d030c10e83))

# [1.3.0](https://github.com/BenTenmann/setriq/compare/deploy-1.2.1...deploy-1.3.0) (2021-12-18)


### Features

* update cdr-dist to have thakkar default ([0e312f6](https://github.com/BenTenmann/setriq/commit/0e312f680e5e8645f8950fc40479501c8df3bd6e))

## [1.2.1](https://github.com/BenTenmann/setriq/compare/deploy-1.2.0...deploy-1.2.1) (2021-12-18)


### Bug Fixes

* setup flags ([daca55f](https://github.com/BenTenmann/setriq/commit/daca55f37438f9485695eaa843fe24f686c47b07))

# [1.2.0](https://github.com/BenTenmann/setriq/compare/deploy-1.1.2...deploy-1.2.0) (2021-12-17)


### Features

* pypi release ([24549a4](https://github.com/BenTenmann/setriq/commit/24549a4ee3614b58fadc18b3cbe734f9300ac32a))

## [1.1.2](https://github.com/BenTenmann/setriq/compare/deploy-1.1.1...deploy-1.1.2) (2021-12-17)


### Bug Fixes

* update build flag selection ([a62b482](https://github.com/BenTenmann/setriq/commit/a62b482c96acc79a41085594612f0058c0a2f7b0))

## [1.1.1](https://github.com/BenTenmann/setriq/compare/deploy-1.1.0...deploy-1.1.1) (2021-12-17)


### Bug Fixes

* sdist include ([dd7bc20](https://github.com/BenTenmann/setriq/commit/dd7bc2014c61e5d005232743c956be0c2c44accd))

# [1.1.0](https://github.com/BenTenmann/setriq/compare/deploy-1.0.2...deploy-1.1.0) (2021-12-16)


### Features

* update README ([530ba17](https://github.com/BenTenmann/setriq/commit/530ba171ff4ed23799151c11f40a44b3fac6a8f9))

## [1.0.2](https://github.com/BenTenmann/setriq/compare/deploy-1.0.1...deploy-1.0.2) (2021-12-16)


### Bug Fixes

* update cci config ([df6030a](https://github.com/BenTenmann/setriq/commit/df6030a400d9f93dde9854ed52dec2aedad72667))

## [1.0.1](https://github.com/BenTenmann/setriq/compare/deploy-1.0.0...deploy-1.0.1) (2021-12-16)


### Bug Fixes

* give releaseImage.sh execution permission ([6aded34](https://github.com/BenTenmann/setriq/commit/6aded3440baad07faa2467e8b52203803f7391c1))

# 1.0.0 (2021-12-16)


### Bug Fixes

* add --user to pip install ([1afecef](https://github.com/BenTenmann/setriq/commit/1afecefe6b9b485805eaeba385a42f28532bd697))
* add -e ([6f72f8c](https://github.com/BenTenmann/setriq/commit/6f72f8c6f1cb8f8e7e0d4451045cf2dbe9b940c3))
* add cstring header ([fddb517](https://github.com/BenTenmann/setriq/commit/fddb517050489ab3632b94a22b0514a93f75a597))
* add pip to install ([927c05f](https://github.com/BenTenmann/setriq/commit/927c05fad3a9770c493b3dbe3d1b0e2efdb67387))
* add pybind11 dependency to release job ([6d2a58d](https://github.com/BenTenmann/setriq/commit/6d2a58dbe7dd1d988c998c8d077e0f728199eadd))
* add pytest-cov ([f497b7a](https://github.com/BenTenmann/setriq/commit/f497b7a25dfafac4d26485fec08d0bb1b99eaa08))
* add semi-colo ([c19335b](https://github.com/BenTenmann/setriq/commit/c19335b587ebebd696b6a32e595998d3f8c741aa))
* change compile + link args ([97de5e0](https://github.com/BenTenmann/setriq/commit/97de5e0b8c457dd403a99db8d8441895b39d23e3))
* change compile flags based on platform ([9bf72d5](https://github.com/BenTenmann/setriq/commit/9bf72d5dd7b948799f231cbd8e8f8faa985d4c26))
* install libomp-dev ([133595f](https://github.com/BenTenmann/setriq/commit/133595f26a2b4342b731a5a667d15185c642dc98))
* new gcc comile args ([387e9ba](https://github.com/BenTenmann/setriq/commit/387e9ba2c20eda6483cf4de37b1b70721f3ea627))
* remove --user flag ([dadaba9](https://github.com/BenTenmann/setriq/commit/dadaba9717b0f01e75407760845e362aac87998b))
* restructure package ([1e87d25](https://github.com/BenTenmann/setriq/commit/1e87d2563c41811ad9d929f391a8e7df96a3b6d7))
* semrel git link ([468cce8](https://github.com/BenTenmann/setriq/commit/468cce871e39137999f3c4dee453a9eb14358988))
* semrel vulnerability ([c1d4f38](https://github.com/BenTenmann/setriq/commit/c1d4f380568933fb6e5b2c70a5e42ad36dbc103a))
* try newer python version ([e2b0e6d](https://github.com/BenTenmann/setriq/commit/e2b0e6d7cbc9cdfd5c894744a056aef6067a6d7a))
* update cci executor ([a3451bc](https://github.com/BenTenmann/setriq/commit/a3451bc5b552f51012baab00aac5fde6957a0fce))
* update compile args ([fd617a4](https://github.com/BenTenmann/setriq/commit/fd617a40bb41eaecf775271f4c0592970a332a15))
* update input key check tcr-dist ([45ece4e](https://github.com/BenTenmann/setriq/commit/45ece4eb931db406e441d204b34beb2e8e5c0c75))
* update setup.py package data ([b1dd192](https://github.com/BenTenmann/setriq/commit/b1dd192ab165b51dc4c52f9c33ecc95a289a484f))
* update tests ([15cacf3](https://github.com/BenTenmann/setriq/commit/15cacf3c41400841d9231fc57411300cfcd3c4ad))
* update to pip install -e ([62318e8](https://github.com/BenTenmann/setriq/commit/62318e8e405c330d678be206ffd3a8934c47e828))


### Features

* add back CMakeList.txt for testing ([635a4b1](https://github.com/BenTenmann/setriq/commit/635a4b1e5ab8a92ab5267ff19f3899e1e98e7bb0))
* add cci ([ae45ee9](https://github.com/BenTenmann/setriq/commit/ae45ee91fac06578ca0613350946799db70f5665))
* add cdr-2.5 component to tcr-dist ([7c6aa32](https://github.com/BenTenmann/setriq/commit/7c6aa327f8311fbf0cb945205af69b56ccd43803))
* add convenience method on substitution matrix ([c14840b](https://github.com/BenTenmann/setriq/commit/c14840bce2eb4f55ac10ce511746a418180be0fa))
* add levenshtein ([c3e3524](https://github.com/BenTenmann/setriq/commit/c3e3524db7721815829ca4b48bf571ff6e0385e6))
* add levenshtein test ([198025e](https://github.com/BenTenmann/setriq/commit/198025eac366c2186d46caf2203996736cefa261))
* add license and delete CMakeList.txt ([673bb55](https://github.com/BenTenmann/setriq/commit/673bb55a7b85ba5dee0c29356d7a3f49366b0ae9))
* add logo ([d687e3c](https://github.com/BenTenmann/setriq/commit/d687e3c451b9cb594b28283001c8fc0534cdf90a))
* add modules and data ([5da7c0e](https://github.com/BenTenmann/setriq/commit/5da7c0ecd752582dc39b045071b87577c1f65497))
* add more distances tests ([9bf6215](https://github.com/BenTenmann/setriq/commit/9bf6215ee001ae03fcb986af301d18304bc64a67))
* add more distances tests++ ([400049d](https://github.com/BenTenmann/setriq/commit/400049ddc656750519e8c3de744fc876fa64113d))
* add more substitution tests ([c17c71c](https://github.com/BenTenmann/setriq/commit/c17c71c7d6cdaf7bec3753f913f7864a93fdabb0))
* add parallel processing ([8c72e23](https://github.com/BenTenmann/setriq/commit/8c72e23600bb23aebe02fcd059ede39416f3ed97))
* add semantic release ([3f022bd](https://github.com/BenTenmann/setriq/commit/3f022bd241af6991140eb036aa3a9f94c729d741))
* add substitution tests ([eec9b79](https://github.com/BenTenmann/setriq/commit/eec9b7984438ad17e37b55da5b9eac62ff3c51fd))
* add tcr sub-mat default ([293995d](https://github.com/BenTenmann/setriq/commit/293995d56b59811b0398d28a6925c8d283393ffc))
* add tcr-dist ([c2809cf](https://github.com/BenTenmann/setriq/commit/c2809cf5d134aaebbcdbb4026eacad95d5f69d65))
* add tests ([f4f842a](https://github.com/BenTenmann/setriq/commit/f4f842a4cf97c6ebb58e1c772a61c728c497161c))
* bind tcr_dist_component ([fcc26d3](https://github.com/BenTenmann/setriq/commit/fcc26d3cb721d36fd632bcddf9a1495122339a76))
* data-structure speed-bump ([25127f3](https://github.com/BenTenmann/setriq/commit/25127f35347855687256c4aeeece61b5b3361172))
* expose TcrDist to parent package ([858bc90](https://github.com/BenTenmann/setriq/commit/858bc9018c92f4469d986168abc69e71cfa36de3))
* initial commit ([a64f8ea](https://github.com/BenTenmann/setriq/commit/a64f8ead335f95a743e8a5c85c8a7ff1790fca46))
